[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / OwnershipProof

# Interface: OwnershipProof

Base interface for proving ownership of an account or address

## Remarks

TheOwnershipProof interface provides a common structure for different types of ownership verification:
- All proofs must specify their type from the supported ProofTypes enum
- Current verification status is tracked via ProofStatus
- Links the proof to a decentralized identifier (DID)
- Specifies the blockchain account/address being proven using CAIP-10 format

This interface is extended by specific proof types like:
- SignatureProof for cryptographic signatures
- DeclarationProof for self-declarations
- MicroTransferProof for transaction-based proof
- ScreenshotProof for image-based verification

## See

 - [ProofTypes](../enumerations/ProofTypes.md) For supported proof methods
 - [ProofStatus](../enumerations/ProofStatus.md) For possible verification states
 - [CAIP10](../type-aliases/CAIP10.md) For address format specification

## Extended by

- [`SignatureProof`](SignatureProof.md)
- [`DeclarationProof`](DeclarationProof.md)
- [`ConnectionRecord`](ConnectionRecord.md)
- [`MicroTransferProof`](MicroTransferProof.md)
- [`ScreenshotProof`](ScreenshotProof.md)

## Properties

### address

> **address**: \`$\{string\}:$\{string\}:$\{string\}\`

#### Defined in

[types.ts:1113](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/27e5c6c27d8a3a0bdafefd6e32c1654e964838a3/src/types.ts#L1113)

***

### did

> **did**: \`did:$\{string\}:$\{string\}\`

#### Defined in

[types.ts:1112](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/27e5c6c27d8a3a0bdafefd6e32c1654e964838a3/src/types.ts#L1112)

***

### status

> **status**: [`ProofStatus`](../enumerations/ProofStatus.md)

#### Defined in

[types.ts:1111](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/27e5c6c27d8a3a0bdafefd6e32c1654e964838a3/src/types.ts#L1111)

***

### type

> **type**: [`ProofTypes`](../enumerations/ProofTypes.md)

#### Defined in

[types.ts:1110](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/27e5c6c27d8a3a0bdafefd6e32c1654e964838a3/src/types.ts#L1110)
